# This file was auto-generated by Fern from our API Definition.

import typing
from .z_3_expression import Z3Expression
from .structure_function_call import StructureFunctionCall
from .formalization_error import FormalizationError

Formalization = typing.Union[Z3Expression, StructureFunctionCall, FormalizationError]
